@@ -2,58 +2,42 @@
 #'
 #' When conducting a search or creating a data query, it is common to identify 
 #' a known taxon or group of taxa to narrow down the records or results returned. 
-#' This function allows users to pass scientific names or taxonomic identifiers
-#' with pipes to provide data only for the biological group of interest.
+#'
+#' `galah_identify()` is used to identify taxa you want returned in a search or 
+#' a data query. Users to pass scientific names or taxonomic identifiers
+#' with pipes to provide data only for the biological group of interest. 
+#' 
+#' It is good to use [search_taxa()] and [search_identifiers()] 
+#' first to check that the taxa you provide to `galah_identify()` return the 
+#' correct results.
 #'
 #' @param ... one or more scientific names (if `search = TRUE`) or taxonomic 
 #'   identifiers (if `search = FALSE`); or an object of class `ala_id` (from
 #'   `search_taxa`).
 #' @param search (logical); should the results in question be passed to
-#'   `search_taxa`? Ignored if an object of class `ala_id`, `gbifid`, or `nbnid` 
-#'   is given to `...`.
+#'   `search_taxa`?
 #' @return A tibble containing identified taxa.
 #' @seealso [search_taxa()] to find identifiers from scientific names;
 #' [search_identifiers()] for how to get names if taxonomic identifiers 
 #' are already known.
 #' 
-#' @section Examples:
-#' ```{r, child = "man/rmd/setup.Rmd"}
-#' ```
-#' 
-#' `galah_identify()` is used to identify taxa you want returned in a search or 
-#' a data query. It is good to use [search_taxa()] and [search_identifiers()] 
-#' first to check that the taxa you provide to `galah_identify()` return the 
-#' correct results.
-#' 
-#' Specify a taxon. A valid taxon will return an identifier.
-#' 
-#' ```{r, comment = "#>", collapse = TRUE}
+#' @examples
+#' # Specify a taxon. A valid taxon will return an identifier.
 #' galah_identify("reptilia")
-#' ```
 #' 
-#' Specify more than one taxon at a time.
-#' 
-#' ```{r, comment = "#>", collapse = TRUE}
+#' # Specify more than one taxon at a time.
 #' galah_identify("reptilia", "mammalia", "aves", "pisces")
-#' ```
 #' 
-#' Use `galah_identify()` to narrow your queries
-#' 
-#' ```{r, comment = "#>", collapse = TRUE}
+#' # Use `galah_identify()` to narrow your queries
 #' galah_call() |> 
 #'   galah_identify("Eolophus") |>
 #'   atlas_counts()
-#' ```
 #' 
-#' If you already know a valid taxon identifier, add it and set `search = FALSE`.
-#'
-#' ```{r, comment = "#>", collapse = TRUE}
+#' # If you know a valid taxon identifier, add it and set `search = FALSE`.
 #' galah_call() |> 
 #'   galah_identify("https://biodiversity.org.au/afd/taxa/009169a9-a916-40ee-866c-669ae0a21c5c", 
 #'                  search = FALSE) |>
 #'   atlas_counts()
-#' ```
-#' 
 #' 
 #' @export
 galah_identify <- function(..., search = TRUE) {
@@ -68,7 +52,16 @@ galah_identify <- function(..., search = TRUE) {
   } else {
     is_data_request <- FALSE
   }
+  
+  if (is_data_request) {
+    update_galah_call(data_request, identify = parse_identify(dots, search))
+  } else {
+    parse_identify(dots, search)
+  }
+}
 
+
+parse_identify <- function(dots, search){
   if (length(dots) > 0) {
 
     # basic checking
@@ -76,23 +69,20 @@ galah_identify <- function(..., search = TRUE) {
     input_query <- parse_basic_quosures(dots) # convert dots to query
 
     # get cached behaviour
-    atlas <- getOption("galah_config")$atlas
-    run_checks <- getOption("galah_config")$run_checks
-    verbose <- getOption("galah_config")$verbose
+    atlas <- getOption("galah_config")$atlas$region
+    run_checks <- getOption("galah_config")$package$run_checks
+    verbose <- getOption("galah_config")$package$verbose
 
     # check for types first
     if (!is.null(attr(input_query, "call"))) {
       query <- input_query$taxon_concept_id
-    # } else if (inherits(input_query, c("gbifid+", "nbnid+"))) { # from taxize
-    #   query <- as.character(input_query)
     } else { # if the input isn't of known type, try to find IDs
       if (search) {
-        check_atlas(atlas)
         lookup <- search_taxa(input_query)
         if (!any(names(lookup) == "taxon_concept_id")){
           bullets <- c(
             "`galah_identify` didn't return anything.",
-            i = "Did you use `search_taxa` to check whether your search species the correct taxa?"
+            i = "Did you use `search_taxa` to check whether your search specifies the correct taxa?"
           )
           abort(bullets, call = caller_env())
         } else {
@@ -133,11 +123,7 @@ galah_identify <- function(..., search = TRUE) {
 
   # if a data request was supplied, return one
   attr(result, "call") <- "galah_identify"
-  if (is_data_request) {
-    update_galah_call(data_request, identify = result)
-  } else {
-    result
-  }
+  return(result)
 }
 
 
@@ -164,20 +150,6 @@ check_number_returned <- function(n_in, n_out, error_call = caller_env()) {
   }
 }
 
-check_atlas <- function(atlas, error_call = caller_env()) {
-  if(atlas == "UK"){
-    # atlas_origin <- switch(atlas,
-    #   "UK" = "UK",
-    #   "Sweden" = "Swedish",
-    #   "Austria" = "Austrian",
-    #   "Guatemala" = "Guatemalan",
-    #   "Spain" = "Spanish"
-    # )
-    bullets <- c("Searching is not supported for the NBN.")
-    abort(bullets, call = error_call)
-  }
-}
-
 
 # it is possible that the above will lead to non-character 
 # arguments being passed (if search = FALSE and run_checks = FALSE)
@@ -194,4 +166,4 @@ check_is_character <- function(query, error_call = caller_env()){
     )
     abort(bullets, call = error_call)
   }
-}
\ No newline at end of file
+}
